==> vst3sdk-docs-3.7.13_build_42-1-any.pkg.tar.zst: usr/share/doc/vst3sdk-docs/vstsdk/dir_9d0a1c96bcf639e3da34210cb03957b4.js <==
var dir_9d0a1c96bcf639e3da34210cb03957b4 =
[
    [ "connectionproxy.cpp", "connectionproxy_8cpp.html", "connectionproxy_8cpp" ],
    [ "connectionproxy.h", "connectionproxy_8h.html", [
      [ "ConnectionProxy", "classSteinberg_1_1Vst_1_1ConnectionProxy.html", "classSteinberg_1_1Vst_1_1ConnectionProxy" ]
    ] ],
    [ "eventlist.cpp", "eventlist_8cpp.html", "eventlist_8cpp" ],
    [ "eventlist.h", "eventlist_8h.html", null ],
    [ "hostclasses.cpp", "hostclasses_8cpp.html", "hostclasses_8cpp" ],
    [ "hostclasses.h", "hostclasses_8h.html", null ],
    [ "hostdataexchangehandler.cpp", "hostdataexchangehandler_8cpp.html", null ],
    [ "hostdataexchangehandler.h", "hostdataexchangehandler_8h.html", [
      [ "IDataExchangeHandlerHost", "structSteinberg_1_1Vst_1_1IDataExchangeHandlerHost.html", "structSteinberg_1_1Vst_1_1IDataExchangeHandlerHost" ],
      [ "HostDataExchangeHandler", "structSteinberg_1_1Vst_1_1HostDataExchangeHandler.html", "structSteinberg_1_1Vst_1_1HostDataExchangeHandler" ]
    ] ],
    [ "module.cpp", "module_8cpp.html", null ],
    [ "module.h", "module_8h.html", [
      [ "FactoryInfo", "classVST3_1_1Hosting_1_1FactoryInfo.html", "classVST3_1_1Hosting_1_1FactoryInfo" ],
      [ "ClassInfo", "classVST3_1_1Hosting_1_1ClassInfo.html", "classVST3_1_1Hosting_1_1ClassInfo" ],
      [ "ClassInfo::Data", "structVST3_1_1Hosting_1_1ClassInfo_1_1Data.html", "structVST3_1_1Hosting_1_1ClassInfo_1_1Data" ],
      [ "PluginFactory", "classVST3_1_1Hosting_1_1PluginFactory.html", "classVST3_1_1Hosting_1_1PluginFactory" ],
      [ "Module", "classVST3_1_1Hosting_1_1Module.html", "classVST3_1_1Hosting_1_1Module" ],
      [ "Module::Snapshot", "structVST3_1_1Hosting_1_1Module_1_1Snapshot.html", "structVST3_1_1Hosting_1_1Module_1_1Snapshot" ],
      [ "Module::Snapshot::ImageDesc", "structVST3_1_1Hosting_1_1Module_1_1Snapshot_1_1ImageDesc.html", "structVST3_1_1Hosting_1_1Module_1_1Snapshot_1_1ImageDesc" ]
    ] ],
    [ "module_linux.cpp", "module__linux_8cpp.html", "module__linux_8cpp" ],
    [ "module_mac.mm", "module__mac_8mm.html", "module__mac_8mm" ],
    [ "module_win32.cpp", "module__win32_8cpp.html", "module__win32_8cpp" ],
    [ "parameterchanges.cpp", "parameterchanges_8cpp.html", "parameterchanges_8cpp" ],
    [ "parameterchanges.h", "parameterchanges_8h.html", [
      [ "ParameterValueQueue::ParameterQueueValue", "structSteinberg_1_1Vst_1_1ParameterValueQueue_1_1ParameterQueueValue.html", "structSteinberg_1_1Vst_1_1ParameterValueQueue_1_1ParameterQueueValue" ],
      [ "ParameterChangeTransfer::ParameterChange", "structSteinberg_1_1Vst_1_1ParameterChangeTransfer_1_1ParameterChange.html", "structSteinberg_1_1Vst_1_1ParameterChangeTransfer_1_1ParameterChange" ]
    ] ],
    [ "pluginterfacesupport.cpp", "pluginterfacesupport_8cpp.html", null ],
    [ "pluginterfacesupport.h", "pluginterfacesupport_8h.html", null ],
    [ "plugprovider.cpp", "plugprovider_8cpp.html", null ],
    [ "plugprovider.h", "plugprovider_8h.html", [
      [ "PlugProvider", "classSteinberg_1_1Vst_1_1PlugProvider.html", "classSteinberg_1_1Vst_1_1PlugProvider" ],
      [ "PluginContextFactory", "classSteinberg_1_1Vst_1_1PluginContextFactory.html", "classSteinberg_1_1Vst_1_1PluginContextFactory" ]
    ] ],
    [ "processdata.cpp", "processdata_8cpp.html", null ],
    [ "processdata.h", "processdata_8h.html", null ]
];

==> vst3sdk-docs-3.7.14_build_55-1-any.pkg.tar.zst: usr/share/doc/vst3sdk-docs/vstsdk/dir_9d0a1c96bcf639e3da34210cb03957b4.js <==
var dir_9d0a1c96bcf639e3da34210cb03957b4 =
[
    [ "connectionproxy.cpp", "connectionproxy_8cpp.html", "connectionproxy_8cpp" ],
    [ "connectionproxy.h", "connectionproxy_8h.html", "connectionproxy_8h" ],
    [ "eventlist.cpp", "eventlist_8cpp.html", "eventlist_8cpp" ],
    [ "eventlist.h", "eventlist_8h.html", null ],
    [ "hostclasses.cpp", "hostclasses_8cpp.html", "hostclasses_8cpp" ],
    [ "hostclasses.h", "hostclasses_8h.html", null ],
    [ "hostdataexchangehandler.cpp", "hostdataexchangehandler_8cpp.html", null ],
    [ "hostdataexchangehandler.h", "hostdataexchangehandler_8h.html", "hostdataexchangehandler_8h" ],
    [ "module.cpp", "module_8cpp.html", null ],
    [ "module.h", "module_8h.html", "module_8h" ],
    [ "module_linux.cpp", "module__linux_8cpp.html", "module__linux_8cpp" ],
    [ "module_mac.mm", "module__mac_8mm.html", "module__mac_8mm" ],
    [ "module_win32.cpp", "module__win32_8cpp.html", "module__win32_8cpp" ],
    [ "parameterchanges.cpp", "parameterchanges_8cpp.html", "parameterchanges_8cpp" ],
    [ "parameterchanges.h", "parameterchanges_8h.html", "parameterchanges_8h" ],
    [ "pluginterfacesupport.cpp", "pluginterfacesupport_8cpp.html", null ],
    [ "pluginterfacesupport.h", "pluginterfacesupport_8h.html", null ],
    [ "plugprovider.cpp", "plugprovider_8cpp.html", null ],
    [ "plugprovider.h", "plugprovider_8h.html", "plugprovider_8h" ],
    [ "processdata.cpp", "processdata_8cpp.html", null ],
    [ "processdata.h", "processdata_8h.html", null ]
];
